#
# spec file for package lrslib
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define dullver	073
%define dullver2 073
%define lname   liblrs1
Name:           lrslib
Version:        7.3
Release:        1.3
Summary:        Reverse Search Vertex Enumeration program
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            http://cgm.cs.mcgill.ca/~avis/C/lrs.html
Source:         http://cgm.cs.mcgill.ca/~avis/C/lrslib/archive/%name-%dullver.tar.gz
Patch1:         lrs-128.diff
Patch2:         lrs-compile.diff
Patch3:         lrs-types.diff
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libtool >= 2

%description
lrslib is a library for the reverse search algorithm for vertex
enumeration/convex hull problems and comes with a choice of three
arithmetic packages. Input file formats are compatible with the
cddlib package. All computations are done exactly in either
multiple precision or fixed integer arithmetic. Output is not stored
in memory, so even problems with very large output sizes can
sometimes be solved.

%package -n %lname
Summary:        Reverse Search Vertex Enumeration library
Group:          System/Libraries

%description -n %lname
lrslib is a library for the reverse search algorithm for vertex
enumeration/convex hull problems and comes with a choice of three
arithmetic packages. Input file formats are compatible with the
cddlib package. Computations are done in multiprecision
arithmetic.

%package devel
Summary:        Development files for Reverse Search Vertex Enumeration
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
lrslib is a library for the reverse search algorithm for vertex
enumeration/convex hull problems and comes with a choice of three
arithmetic packages.

This subpackage contains libraries and header files for developing
applications that want to make use of lrslib.

%prep
%autosetup -n %name-%dullver -p1

%build
%make_build CFLAGS="%optflags -Ilrsarith-011" CXXFLAGS="%optflags -Ilrsarith-011" \
	PACKAGE_VERSION="%version" all-shared

%install
%make_install prefix="%_prefix" PACKAGE_VERSION="%version"
# stupid things
if [ "%_lib" != lib ]; then
	mkdir -p "%buildroot/%_libdir"
	mv "%buildroot/%_libdir/../lib"/* "%buildroot/%_libdir/"
fi
chmod a-x COPYING README "%buildroot/%_includedir/lrslib"/*.h

%ldconfig_scriptlets -n %lname

%files
%_bindir/*
%license COPYING
%doc README

%files -n %lname
%_libdir/liblrs.so.1*

%files devel
%_includedir/lrslib/
%_libdir/liblrs.so

%changelog
* Sun Feb  9 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 7.3
  * lrs is now multithreaded with limited parallelization on a
    shared memory machine using OpenMP. lrs now evaluates in
    parallel all children of the root in the search tree.
  * minrep finds any hidden linearities and removes redundancy
    giving a H/V description with minimum number of rows.
  * `mplrs -minrep`: Fully parallelized version of minrep,
    replaces `mplrs -redund`.
  * `mplrs -fel` Does a fully parallel LP redundancy removal in
    one step of Fourier-Motzin elimination.
  * New features:
  * Checks equivalency between H/V representations (possibly
    after projections) using SMT solvers, see the polyv man page
    for details.
* Sat Jul 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 7.2
  * Projecting a polyhedron to a subset of its variables (Fourier
    elimination)
  * Determining if an inequality is redundant in computing the
    projection to a subset of its variables (uses SMT solver)
* Fri Jun 25 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 7.1b
  * Fixed an issue where output can be lost in arithmetic change.
  * Place lrsrestart.h into buildroot upon `make install`.
* Thu Dec 24 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 7.1a
  * Fixed memory leak in countonly option for mplrs/lrs.
* Sat Jun  6 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 7.1
  * lrs: redund function is now performed by lrs via options, but
    legacy redund maintained.
  * lrs: extract option to extract columns from the input especially
    with linearities.
  * lrs: hvref makes a cross reference list between H and V
    representations.
  * mplrs: Temporary files no longer used for communicating with
    workers.
  * mplrs: Parallel version of redund is now available.
- Drop lrs-version.diff. Add lrs-types.diff.
* Mon Nov  4 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 7.0a
  * Misplaced leaf test degraded performance and has been fixed.
  * Bug in volume computation in mplrs fixed.
  * Default cache limit set back to 10 to allow large parallel
    runs with low memory.
  * Reintroduced buffer for removing most duplicates when
    allbases option is set.
  * lrs1/2 on overflow no longer gives core dump.
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to upstream rerelease 7.0
  (replacing tarballs sucks, upstream!)
  - -- lrslib-070~/lrslib.c 2018-06-25 12:30:34.000000000 +0200
  +++ lrslib-070/lrslib.c 2018-10-23 08:22:44.000000000 +0200
* Sat Oct 20 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 7.0
  * hybrid (64bit/128bit/GMP) arithmetic implemented:
  * speedups of roughly 3-5 times (64bit) and 2 times(128bit)
    over GMP for problems using small integers.
  * overflow checking for 64/128 bit arithmetic
  * __int128 (gcc v.4.6.0 or later) and FLINT arithmetic now supported
  * lrsgmp, mplrsgmp uses only GMP arithmetic, same as lrslib-062
  * lrs/redund/mplrs start in 64 bit moving to 128 bit and then
    to gmp arithmetic as necessary.
  * single arithmetic versions of lrs/mplrs available for
    comparison purposes.
  * single arithmetic versions of lrsnash are available with
    overflow checking.
  * plrs is no longer supported
  * removing the -DSAFE option disables overflow checking in
    64/128 bit mode and results are unpredicable if overflow
    occurs.
  * mplrs now prints maximum tree depth at end and supports
    printcobasis option in input files.
- Drop lrs-am.diff (no longer wanted). Add lrs-version.diff
  and lrs-128.diff.
* Sat Jun 23 2018 jengelh@inai.de
- lrs-am.diff: add -lpthread for programs using boost_thread
* Tue Feb 21 2017 jengelh@inai.de
- Update to new upstream release 062
  * New command-line options -countonly, -stopafter <n>, -maxbuf <n>.
  * Volume output.
  * Counting statistics on number of jobs, size of L, number of
    times empty changed to longs.
  * Performance improvements for problems with large outputs.
* Sun Mar 27 2016 jengelh@inai.de
- Initial package (version 061) for build.opensuse.org
